@@ -267,12 +267,13 @@ class And(ParseExpression):
                 continue
             try:
                 result = expr._parse(string, index, doActions)
+                acc.append(result)
+
                 end = result.end
                 if end > index:
                     failures = result.failures
                 else:
                     failures.extend(result.failures)
-                acc.append(result)
             except ParseException as pe:
                 if encountered_syntax_error:
                     raise ParseSyntaxException(pe.expr, pe.loc, pe.string, cause=pe)
@@ -296,6 +297,11 @@ class And(ParseExpression):
             if e.min_length():
                 return
 
+    def reverse(self):
+        return And(
+            [e.reverse() for e in self.exprs[::-1]], self.parser_config.whitespace
+        )
+
     def __regex__(self):
         return "+", "".join(regex_iso(*e.__regex__(), "+") for e in self.exprs)
 
@@ -391,7 +397,9 @@ class Or(ParseExpression):
         if len(matches) == 1:
             _, expr = matches[0]
             result = expr._parse(string, start, doActions)
-            return ParseResults(self, result.start, result.end, [result], result.failures)
+            return ParseResults(
+                self, result.start, result.end, [result], result.failures
+            )
 
         if matches:
             # re-evaluate all matches in descending order of length of match, in case attached actions
@@ -403,7 +411,9 @@ class Or(ParseExpression):
                 # alternative, so the first match will be the best match
                 _, expr = matches[0]
                 result = expr._parse(string, start, doActions)
-                return ParseResults(self, result.start, result.end, [result], result.failures)
+                return ParseResults(
+                    self, result.start, result.end, [result], result.failures
+                )
 
             longest = -1, None
             for loc, expr in matches:
@@ -417,12 +427,20 @@ class Or(ParseExpression):
                     failures.append(err)
                 else:
                     if result.end >= loc:
-                        return ParseResults(self, result.start, result.end, [result], result.failures)
+                        return ParseResults(
+                            self, result.start, result.end, [result], result.failures
+                        )
                     # didn't match as much as before
                     elif result.end > longest[0]:
                         longest = (
                             result.end,
-                            ParseResults(self, result.start, result.end, [result], result.failures),
+                            ParseResults(
+                                self,
+                                result.start,
+                                result.end,
+                                [result],
+                                result.failures,
+                            ),
                         )
 
             if longest != (-1, None):
@@ -485,7 +503,9 @@ class MatchFirst(ParseExpression):
         for e in self.alternate:
             try:
                 result = e._parse(string, start, doActions)
-                return ParseResults(self, result.start, result.end, [result], result.failures)
+                return ParseResults(
+                    self, result.start, result.end, [result], result.failures
+                )
             except ParseException as cause:
                 causes.append(cause)
 
@@ -755,7 +775,7 @@ class MatchAll(ParseExpression):
                     start,
                     string,
                     "Missing minimum (%i) more required elements (%s)" % (mi, e),
-                    cause=failures
+                    cause=failures,
                 )
 
         found = set(id(m) for m in matchOrder)
@@ -767,7 +787,11 @@ class MatchAll(ParseExpression):
         if missing:
             missing = ", ".join(text(e) for e in missing)
             raise ParseException(
-                self, start, string, f"Missing one or more required elements ({missing})", failures
+                self,
+                start,
+                string,
+                f"Missing one or more required elements ({missing})",
+                failures,
             )
 
         # add any unmatched Optionals, in case they have default values defined
